mercurial/cext/manifest.c
changeset 40765 7e6834ade51d
parent 40601 da4478ca0e32
child 44100 969527ac7b44
--- a/mercurial/cext/manifest.c	Sun Nov 11 20:05:38 2018 +0900
+++ b/mercurial/cext/manifest.c	Thu Nov 29 16:44:01 2018 -0500
@@ -127,11 +127,11 @@
 		if (!next) {
 			return MANIFEST_MALFORMED;
 		}
-		if ((next - data) < 22) {
-			/* We should have at least 22 bytes in a line:
+		if ((next - data) < 42) {
+			/* We should have at least 42 bytes in a line:
 			   1 byte filename
 			   1 NUL
-			   20 bytes of hash
+			   40 bytes of hash
 			   so we can give up here.
 			*/
 			return MANIFEST_TOO_SHORT_LINE;